pub struct FaultDeclarationAPI {
pub deadline: u64,
pub partition: u64,
pub sectors: BitField,
}Fields
deadline: u64The deadline to which the faulty sectors are assigned, in range [0..WPoStPeriodDeadlines)
partition: u64Partition index within the deadline containing the faulty sectors.
sectors: BitFieldSectors in the partition being declared faulty.
Implementations
Sourceimpl FaultDeclarationAPI
impl FaultDeclarationAPI
pub fn serialize<__S>(
__self: &FaultDeclaration,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,
Sourceimpl<'de> FaultDeclarationAPI
impl<'de> FaultDeclarationAPI
pub fn deserialize<__D>(
__deserializer: __D,
) -> Result<FaultDeclaration, __D::Error>where
__D: Deserializer<'de>,