pub struct RecoveryDeclarationAPI {
pub deadline: u64,
pub partition: u64,
pub sectors: BitField,
}Fields
deadline: u64The deadline to which the recovered sectors are assigned, in range [0..WPoStPeriodDeadlines)
partition: u64Partition index within the deadline containing the recovered sectors.
sectors: BitFieldSectors in the partition being declared recovered.
Implementations
Sourceimpl RecoveryDeclarationAPI
impl RecoveryDeclarationAPI
pub fn serialize<__S>(
__self: &RecoveryDeclaration,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,
Sourceimpl<'de> RecoveryDeclarationAPI
impl<'de> RecoveryDeclarationAPI
pub fn deserialize<__D>(
__deserializer: __D,
) -> Result<RecoveryDeclaration, __D::Error>where
__D: Deserializer<'de>,